Struct html_bindgen::merge::MergedElement
source · pub struct MergedElement {
pub tag_name: String,
pub struct_name: String,
pub submodule_name: String,
pub mdn_link: String,
pub has_global_attributes: bool,
pub has_closing_tag: bool,
pub attributes: Vec<Attribute>,
pub dom_interface: String,
pub content_categories: Vec<MergedCategory>,
pub permitted_child_elements: Vec<String>,
}Expand description
The final source of truth we used to generate code from.
Created by combining all of the previously parsed data.
Fields
tag_name: Stringstruct_name: Stringsubmodule_name: Stringmdn_link: Stringhas_global_attributes: boolhas_closing_tag: boolattributes: Vec<Attribute>dom_interface: Stringcontent_categories: Vec<MergedCategory>permitted_child_elements: Vec<String>Trait Implementations
sourceimpl Clone for MergedElement
impl Clone for MergedElement
sourcefn clone(&self) -> MergedElement
fn clone(&self) -> MergedElement
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for MergedElement
impl Debug for MergedElement
sourceimpl<'de> Deserialize<'de> for MergedElement
impl<'de> Deserialize<'de> for MergedElement
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more